/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.service;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.Query;

import ch.hortis.sonar.model.Snapshot;

/**
 * Class to obtain {@link ch.hortis.sonar.model.Snapshot} from the persistence layer.
 *
 * @see ch.hortis.sonar.model.Snapshot
 */
public class SnapshotService extends Service {

  public SnapshotService(EntityManager manager) {
    super(manager);
  }
  
  public List<Snapshot> getSnapshotsForGivenDay(Integer projectId, Date day) throws NoResultException {
    Calendar cal = Calendar.getInstance();
    cal.setTime(day);
    Query query = manager.createNamedQuery(Snapshot.SQL_SELECT_FOR_DAY);
    query.setParameter("idProject", projectId);
    query.setParameter("day", cal.get(Calendar.DAY_OF_MONTH));
    query.setParameter("month", cal.get(Calendar.MONTH) + 1);
    query.setParameter("year", cal.get(Calendar.YEAR));
    query.setParameter("status", Snapshot.STATUS_PROCESSED);
    List snapshots = query.getResultList();
    if (snapshots.isEmpty()) {
      throw new NoResultException();
    }
    return snapshots;
  }
  
  public Collection<Snapshot> getChildSnapshots( Snapshot snapshot, boolean includeSubmodules ) {
    Collection<Snapshot> result = new ArrayList<Snapshot>();
    Query query = manager.createNamedQuery( Snapshot.SQL_SELECT_BY_PARENT_SNAPSHOT_ID );
    query.setParameter("parent", snapshot );
    Collection<Snapshot> childrens = query.getResultList();
    result.addAll( childrens );
    if (includeSubmodules) {
      for (Snapshot child : childrens) {
        Collection<Snapshot> subchildrens = getChildSnapshots(child, true);
        result.addAll( subchildrens );
      }
    }
    return result;
  }

}
