package org.sonar.commons.database;

import javax.persistence.EntityManager;

public class BatchSaver {
  // IMPORTANT : this value must be the same than the property hibernate.jdbc.batch_size from /META-INF/persistence.xml :
  public static final int BATCH_SIZE = 25;

  private EntityManager entityManager = null;
  private int index = 0;

  public BatchSaver(EntityManager em) {
    this.entityManager = em;
  }

  public void begin() {
    entityManager.getTransaction().begin();
    index = 0;
  }

  public void commit() {
    flush();
    entityManager.getTransaction().commit();
    entityManager.close();
  }

  public void rollback() {
    entityManager.getTransaction().rollback();
    entityManager.close();
  }

  public void save(Object model) {
    entityManager.persist(model);
    if (index%BATCH_SIZE==0) {
      flush();
      index++;
    }
  }

  private void flush() {
    entityManager.flush();
    entityManager.clear();
  }
}
